@@ -1,7 +1,7 @@
 /* mpz_root(root, u, nth) --  Set ROOT to floor(U^(1/nth)).
    Return an indication if the result is exact.
 
-Copyright 1999, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
+Copyright 1999, 2000, 2001, 2002, 2003, 2005, 2012 Free Software Foundation, Inc.
 
 This file is part of the GNU MP Library.
 
@@ -18,7 +18,7 @@ License for more details.
 You should have received a copy of the GNU Lesser General Public License
 along with the GNU MP Library.  If not, see http://www.gnu.org/licenses/.  */
 
-#include <stdio.h>  /* for NULL */
+#include <stdio.h>		/* for NULL */
 #include "gmp.h"
 #include "gmp-impl.h"
 
@@ -27,17 +27,17 @@ mpz_root (mpz_ptr root, mpz_srcptr u, unsigned long int nth)
 {
   mp_ptr rootp, up;
   mp_size_t us, un, rootn, remn;
+  TMP_DECL;
 
-  up = PTR(u);
   us = SIZ(u);
 
   /* even roots of negatives provoke an exception */
-  if (us < 0 && (nth & 1) == 0)
+  if (UNLIKELY (us < 0 && (nth & 1) == 0))
     SQRT_OF_NEGATIVE;
 
   /* root extraction interpreted as c^(1/nth) means a zeroth root should
      provoke a divide by zero, do this even if c==0 */
-  if (nth == 0)
+  if (UNLIKELY (nth == 0))
     DIVIDE_BY_ZERO;
 
   if (us == 0)
@@ -50,15 +50,15 @@ mpz_root (mpz_ptr root, mpz_srcptr u, unsigned long int nth)
   un = ABS (us);
   rootn = (un - 1) / nth + 1;
 
-  if (root != NULL)
-    {
-      rootp = MPZ_REALLOC (root, rootn);
-      up = PTR(u);
-    }
+  TMP_MARK;
+
+  /* FIXME: Perhaps disallow root == NULL */
+  if (root != NULL && u != root)
+    rootp = MPZ_REALLOC (root, rootn);
   else
-    {
-      rootp = __GMP_ALLOCATE_FUNC_LIMBS (rootn);
-    }
+    rootp = TMP_ALLOC_LIMBS (rootn);
+
+  up = PTR(u);
 
   if (nth == 1)
     {
@@ -71,9 +71,12 @@ mpz_root (mpz_ptr root, mpz_srcptr u, unsigned long int nth)
     }
 
   if (root != NULL)
-    SIZ(root) = us >= 0 ? rootn : -rootn;
-  else
-    __GMP_FREE_FUNC_LIMBS (rootp, rootn);
+    {
+      SIZ(root) = us >= 0 ? rootn : -rootn;
+      if (u == root)
+	MPN_COPY (up, rootp, rootn);
+    }
 
+  TMP_FREE;
   return remn == 0;
 }
